import React from 'react';
import styled from 'styled-components';

import { blenderCss } from '@clds/blender';
import { globalTheme } from '@clds/component-theme';
import { typography } from '@clds/typography';

export default {
  title: 'Blender/blenderCss',
  component: blenderCss,
};

const Button = styled.button`
  ${blenderCss.populateVariables({
    mode: 'plainContrast',
    variant: 'primary',
    intensity: 'md',
  })};

  &:hover,
  &:focus-visible {
    ${blenderCss.populateVariables({
      mode: 'solidContrast',
      variant: 'primary',
      intensity: 'lg',
    })};
  }

  &:active {
    ${blenderCss.populateVariables({
      mode: 'solidContrast',
      variant: 'primary',
      intensity: 'xl',
    })};
  }

  background-color: ${blenderCss.backgroundFromCssVariables};
  border: 1px solid ${blenderCss.foregroundFromCssVariables};
  padding: ${globalTheme.spacing.md};
  border-radius: ${globalTheme.radius.unstable_new.md};
`;

const LogoIcon = styled.div`
  background: ${blenderCss.foregroundFromCssVariables};
  width: ${globalTheme.spacing.xl};
  height: ${globalTheme.spacing.xl};
  border-radius: 100%;
`;

const Text = styled.p`
  ${blenderCss.typographyFromCssVariables('xs')};
`;

const Intro = styled.p`
  ${typography.sm.regular};
`;

export const Example = () => (
  <>
    <Intro>
      This shape below reads colors and typography only from css variables which
      are defined on a top level.
    </Intro>
    <Button>
      <LogoIcon />
      <Text>Hello</Text>
    </Button>
  </>
);
