// eslint-disable-next-line import/no-extraneous-dependencies
import { mix } from 'polished';
// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useState } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import styled, { css } from 'styled-components';

import type { BlendVariant } from '@clds/blender';
// eslint-disable-next-line import/no-extraneous-dependencies
import { combineValues, globalTheme } from '@clds/component-theme';
// eslint-disable-next-line import/no-extraneous-dependencies
import {
  FieldLayout,
  GroupLayout,
  InlineFieldLayout,
  Label,
} from '@clds/dev-components';
// eslint-disable-next-line @nrwl/nx/enforce-module-boundaries,import/no-extraneous-dependencies
import { RadioGroup, RadioGroupProps } from '@clds/radio';

const generateOptions = (
  options: Array<{ value: string; label: string } | string>,
  prefix: string,
) =>
  options.map((option) => {
    const optionObject =
      typeof option === 'string' ? { value: option, label: option } : option;
    const id = `radio-option-${prefix}-${optionObject.value}`;
    return (
      <InlineFieldLayout
        key={optionObject.value}
        label={<Label htmlFor={id}>{optionObject.label}</Label>}
      >
        <RadioGroup.Radio id={id} value={optionObject.value} />
      </InlineFieldLayout>
    );
  });

export const useConfigPanel = () => {
  const [variant, setVariant] = useState<BlendVariant>('primary');
  const [preview, setPreview] = useState<keyof typeof grid>('low');
  return {
    variant,
    preview,
    panel: (
      <Panel>
        <FieldLayout
          layout="vertical"
          label={<Label>Preview background</Label>}
        >
          <GroupLayout>
            <RadioGroup
              name="radio-group-checkerboard"
              value={preview}
              onChange={setPreview as RadioGroupProps['onChange']}
            >
              {generateOptions(
                [
                  { label: 'Plain', value: 'none' },
                  { label: 'Low grid', value: 'low' },
                  { label: 'High grid', value: 'high' },
                  { label: 'Inverted', value: 'invert' },
                  { label: 'Image', value: 'img' },
                ],
                'checkerboard',
              )}
            </RadioGroup>
          </GroupLayout>
        </FieldLayout>
        <FieldLayout layout="vertical" label={<Label>Variant</Label>}>
          <GroupLayout>
            <RadioGroup
              name="radio-group-variant"
              value={variant}
              onChange={setVariant as RadioGroupProps['onChange']}
            >
              {generateOptions(
                [
                  'primary',
                  'secondary',
                  'error',
                  'warning',
                  'success',
                  'overlay',
                ],
                'variant',
              )}
            </RadioGroup>
          </GroupLayout>
        </FieldLayout>
      </Panel>
    ),
  };
};

const Panel = styled.div`
  padding-right: ${globalTheme.spacing.lg};
`;

const grid = {
  none: { bg: globalTheme.palette.surface, fg: globalTheme.palette.surface },
  low: {
    bg: combineValues(
      globalTheme.palette.contrastHigh,
      globalTheme.palette.surface,
      (c1, c2) => mix(0.04, c1, c2),
    ),
    fg: globalTheme.palette.surface,
  },
  high: { bg: globalTheme.palette.background, fg: globalTheme.palette.surface },
  invert: {
    bg: globalTheme.palette.contrastLow,
    fg: globalTheme.palette.contrastHigh,
  },
  img: {
    img: 'https://res.cloudinary.com/dcopn0ll4/image/upload/v1632502188/production/cld-web-storybook/button/sea.jpg',
  },
};

const gSize = 16;
export const Grid = styled.div<{ grid: keyof typeof grid }>`
  display: grid;
  grid-template-rows: repeat(4, 1fr);
  grid-auto-flow: column;
  grid-gap: ${globalTheme.spacing.lg};
  align-items: center;
  padding: ${globalTheme.spacing.lg};

  ${(props) =>
    props.grid === 'img'
      ? css`
          background: url('${grid.img.img}');
          background-size: cover;
        `
      : chess(grid[props.grid].bg(props), grid[props.grid].fg(props))}
`;
export const chess = (c1: string, c2: string) => css`
  background-color: ${c1};
  background-image: ${css`linear-gradient(45deg, ${c2} 25%, transparent 25%, transparent 75%, ${c2} 75%),
  linear-gradient(45 deg, ${c2} 25 %, transparent 25 %, transparent 75 %, ${c2} 75 %)`};
  background-size: ${gSize}px ${gSize}px;
  background-position: 0 0, ${gSize / 2}px ${gSize / 2}px;
`;
