// eslint-disable-next-line import/no-extraneous-dependencies
import { getLuminance, mix, readableColor } from 'polished';
// eslint-disable-next-line import/no-extraneous-dependencies
import React, { FC } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import styled from 'styled-components';

// eslint-disable-next-line import/no-extraneous-dependencies
import {
  combineValues,
  createVariant,
  globalTheme,
} from '@clds/component-theme';
// eslint-disable-next-line @nrwl/nx/enforce-module-boundaries
import { Cloud } from '@clds/icon';

import { theme } from './ThemeMixinsWithCombineVariant.theme';

const getReadableColorFixed = (color: string, light: string, dark: string) => {
  if (getLuminance(light) < getLuminance(dark)) {
    return readableColor(color, light, dark);
  }
  return readableColor(color, dark, light);
};

const palette = globalTheme.palette;
const variant = createVariant((props: Props) => theme[props.shape][props.type]);
const buttonColor = variant((t) => t.button.color);

const iconFill = combineValues(
  buttonColor,
  palette.contrastHigh,
  palette.contrastInvert,
  getReadableColorFixed,
);

export interface Props {
  shape: 'solid' | 'pill';
  type: 'primary' | 'secondary';
}

const Button = styled.div`
  height: ${globalTheme.spacing.xxl};
  width: ${globalTheme.spacing.xxl};
`;

const Content = styled.div``;

const Root = styled.div<Props>`
  display: inline-flex;
  align-items: center;
  cursor: pointer;

  margin: ${globalTheme.spacing.md};
  box-shadow: ${globalTheme.shadow.sm};
  color: ${palette.contrastHigh};
  &:hover {
    background-color: ${theme.hover.background};
    ${Button} {
      background-color: ${combineValues(buttonColor, iconFill, (v1, v2) =>
        mix(0.9, v1, v2),
      )};
    }
  }

  background-color: ${variant((t) => t.background)};

  &,
  ${Button} {
    border-radius: ${variant((t) => t.border.radius)};
  }
  ${Button} {
    background-color: ${buttonColor};
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
    display: flex;
    justify-content: center;
    align-items: center;
    svg path {
      fill: ${iconFill};
    }
  }
  ${Content} {
    padding: 0 ${globalTheme.spacing.lg};
  }
`;

export const ThemeMixinsWithCombineVariant: FC<Props> = ({
  children,
  type,
  shape,
}) => (
  <Root type={type} shape={shape}>
    <Button>
      <Cloud size="lg" />
    </Button>
    <Content>{children}</Content>
  </Root>
);
