import React from 'react';
import styled from 'styled-components';

import {
  useDesktop,
  useWide,
  useTablet,
  usePhone,
  media,
  checkerboard,
} from '@clds/style-utils';

export default {
  title: 'Style Utils',
};

const Wide = styled.div`
  background-color: red;
  color: #fff;
  height: 200px;

  &::after {
    content: 'Wide';
  }
`;

const Desktop = styled.div`
  background-color: green;
  color: #fff;
  height: 200px;

  &::after {
    content: 'Desktop';
  }
`;

const Tablet = styled.div`
  background-color: brown;
  color: #fff;
  height: 200px;

  &::after {
    content: 'Tablet';
  }
`;

const Phone = styled.div`
  background-color: orange;
  color: #fff;
  height: 200px;

  &::after {
    content: 'Phone';
  }
`;

const Special = styled.div`
  background-color: blue;
  color: #fff;
  display: none;
  height: 200px;
  margin-top: 40px;

  &::after {
    content: 'This is visible only between tablet and wide';
  }

  @media ${media.tablet({ minOnly: true })} and ${media.wide({
      maxOnly: true,
    })} {
    display: block;
  }
`;

export const hooks = () => {
  const Wrapper = () => {
    const isWide = useWide();
    const isDesktop = useDesktop();
    const isTablet = useTablet();
    const isPhone = usePhone();

    return (
      <div>
        {isWide ? (
          <Wide />
        ) : isDesktop ? (
          <Desktop />
        ) : isTablet ? (
          <Tablet />
        ) : isPhone ? (
          <Phone />
        ) : (
          'Default'
        )}

        <Special />
      </div>
    );
  };

  return <Wrapper />;
};

export const mediaQueries = () => {
  const Wrapper = styled.pre`
    color: white;
    background-color: pink;
    width: 100%;
    height: 300px;

    &:after {
      content: 'Default';
    }

    @media ${media.wide()} {
      background-color: red;

      &:after {
        content: 'Wide';
      }
    }

    @media ${media.desktop()} {
      background-color: blue;

      &:after {
        content: 'Desktop';
      }
    }

    @media ${media.tablet()} {
      background-color: purple;

      &:after {
        content: 'Tablet';
      }
    }

    @media ${media.phone()} {
      background-color: green;

      &:after {
        content: 'Phone';
      }
    }
  `;

  return <Wrapper />;
};

export const withCheckerboard = () => {
  const Wrapper = styled.div`
    width: 600px;
    height: 600px;
    ${checkerboard('red', 'black', 20)}
  `;

  return <Wrapper />;
};
