import { type Story } from '@ladle/react';
import React, { FC } from 'react';
import styled from 'styled-components';

import { globalTheme } from '@clds/component-theme';
import Typography, { TypographyProps } from '@clds/typography';

export default { component: Typography, title: 'Typography' };

const TypographyAs: FC<TypographyProps> = (props) => (
  <Typography {...props} as="div" />
);

const NormalTypography = styled(TypographyAs)`
  padding: calc(${(props) => globalTheme.spacing[props.size]} * 0.5 + 5px);
  background-color: ${globalTheme.palette.surface};
`;
const InvertTypography = styled(NormalTypography)`
  background-color: ${globalTheme.palette.primary};
`;
/* eslint-disable max-len */
const OverlayTypography = styled(NormalTypography)`
  background-image: linear-gradient(
      ${globalTheme.palette.overlayDark3},
      ${globalTheme.palette.overlayDark3}
    ),
    url(https://res.cloudinary.com/dcopn0ll4/image/upload/w_600/v1632502188/production/cld-web-storybook/button/sea.jpg);
  background-size: cover;
`;
const OverlayInvertTypography = styled(NormalTypography)`
  background-image: linear-gradient(
      ${globalTheme.palette.overlayLight3},
      ${globalTheme.palette.overlayLight3}
    ),
    url(https://res.cloudinary.com/dcopn0ll4/image/upload/w_600/v1632502188/production/cld-web-storybook/button/sea.jpg);
  background-size: cover;
`;
/* eslint-enable max-len */

export const Default: Story<{ content: string }> = ({ content }) => {
  return (
    <>
      <h3>XXL</h3>
      <span data-test="xxl-section">
        <NormalTypography size="xxl" type="regular">
          {content}
        </NormalTypography>
        <InvertTypography size="xxl" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography size="xxl" type="overlay">
          {content}
        </OverlayTypography>
        <OverlayInvertTypography
          size="xxl"
          type="overlayInvert"
          data-test-specifier="xxl-overlayInvert"
        >
          {content}
        </OverlayInvertTypography>
      </span>

      <h3>XL</h3>
      <span data-test="xl-section">
        <NormalTypography size="xl" type="regular">
          {content}
        </NormalTypography>
        <InvertTypography size="xl" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography size="xl" type="overlay">
          {content}
        </OverlayTypography>
        <OverlayInvertTypography size="xl" type="overlayInvert">
          {content}
        </OverlayInvertTypography>
      </span>

      <h3>LG</h3>
      <span data-test="lg-section">
        <NormalTypography size="lg" type="regular">
          {content}
        </NormalTypography>
        <InvertTypography size="lg" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography
          size="lg"
          type="overlay"
          data-test-specifier="lg-overlay"
        >
          {content}
        </OverlayTypography>
        <OverlayInvertTypography size="lg" type="overlayInvert">
          {content}
        </OverlayInvertTypography>
      </span>

      <h3>MD</h3>
      <span data-test="md-section">
        <NormalTypography size="md" type="highContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="md" type="regular">
          {content}
        </NormalTypography>
        <NormalTypography size="md" type="lowContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="md" type="url">
          {content}
        </NormalTypography>
        <NormalTypography size="md" type="success">
          {content}
        </NormalTypography>
        <NormalTypography size="md" type="warning">
          {content}
        </NormalTypography>
        <NormalTypography size="md" type="error">
          {content}
        </NormalTypography>
        <InvertTypography size="md" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography size="md" type="overlay">
          {content}
        </OverlayTypography>
        <OverlayInvertTypography size="md" type="overlayInvert">
          {content}
        </OverlayInvertTypography>
      </span>

      <h3>SM</h3>
      <span data-test="sm-section">
        <NormalTypography size="sm" type="highContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="sm" type="regular">
          {content}
        </NormalTypography>
        <NormalTypography size="sm" type="lowContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="sm" type="url">
          {content}
        </NormalTypography>
        <NormalTypography size="sm" type="success">
          {content}
        </NormalTypography>
        <NormalTypography size="sm" type="warning">
          {content}
        </NormalTypography>
        <NormalTypography size="sm" type="error">
          {content}
        </NormalTypography>
        <InvertTypography size="sm" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography size="sm" type="overlay">
          {content}
        </OverlayTypography>
        <OverlayInvertTypography size="sm" type="overlayInvert">
          {content}
        </OverlayInvertTypography>
      </span>

      <h3>XS</h3>
      <span data-test="xs-section">
        <NormalTypography size="xs" type="highContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="regular">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="lowContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="disabled">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="url">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="success">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="warning">
          {content}
        </NormalTypography>
        <NormalTypography size="xs" type="error">
          {content}
        </NormalTypography>
        <InvertTypography size="xs" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography size="xs" type="overlay">
          {content}
        </OverlayTypography>
        <OverlayInvertTypography size="xs" type="overlayInvert">
          {content}
        </OverlayInvertTypography>
      </span>

      <h3>XXS</h3>
      <span data-test="xxs-section">
        <NormalTypography size="xxs" type="highContrast">
          {content}
        </NormalTypography>
        <NormalTypography size="xxs" type="regular">
          {content}
        </NormalTypography>
        <NormalTypography size="xxs" type="disabled">
          {content}
        </NormalTypography>
        <NormalTypography size="xxs" type="url">
          {content}
        </NormalTypography>
        <NormalTypography size="xxs" type="success">
          {content}
        </NormalTypography>
        <NormalTypography size="xxs" type="warning">
          {content}
        </NormalTypography>
        <NormalTypography size="xxs" type="error">
          {content}
        </NormalTypography>
        <InvertTypography size="xxs" type="contrastInvert">
          {content}
        </InvertTypography>
        <OverlayTypography size="xxs" type="overlay">
          {content}
        </OverlayTypography>
        <OverlayInvertTypography size="xxs" type="overlayInvert">
          {content}
        </OverlayInvertTypography>
      </span>
    </>
  );
};

Default.args = {
  content: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.',
};
